%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%	MDPI class for LaTeX files	05-02-2014
%%%% 	Each conference has an own class file. There is only one option for the journal
%% %%
%% %%	Class style provided by Stefano Mariani for any information please send an e-mail to:
%% %%		stefano.mariani@polimi.it
%% %%   Modified by:
%% %%		Dietrich Rordorf (rordorf@mdpi.com)
%% %%		Peter Harremoes (entropeter@mdpi.com)
%% %%		Zeno Schumacher (latex@mdpi.com)
%% %%		Maddalena Giulini (latex@mdpi.com)
%% %%		Andres Gartmann (gartmann@mdpi.com) - v1.2
%% %%		Janine Daum (latex@mdpi.com)
%% %%		
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{mdpi}[2014/02/05 MDPI paper class]

\AtEndDocument{\par \cright}

%% To choose the journal
\DeclareOption{energies}{\gdef\@journal{Energies}}

%% Uppercase will have the same effect
\DeclareOption{Energies}{\gdef\@journal{Energies}}

\DeclareOption{journal}{\ClassWarning{mdpi}{You have not specified the journal. The first class option of the document class mdpi specify the journal. The word journal should be replaced by one of the following journal names: actuators, administrativesciences, aerospace, agriculture, agronomy, algorithms, animals, antibiotics, antibodies, antioxidants, appliedsciences, arts, atmosphere, atoms, axioms, behavioralsciences, bioengineering, biology, biomedicines, biomolecules, biosensors, brainsciences, buildings, cancers, catalysts, cells, challenges, chemosensors, children, chromatography, climate, coatings, computation, computers, cosmetics, crystals, dentistryjournal, diagnostics, diseases, diversity, econometrics, economies, education, electronics, energies, entropy, environmentalsciences, environments, fibers, foods, forests, futureinternet, galaxies, games, genes, geosciences, healthcare, humanities, informatics, information, inorganics, insects, ijerph, ijfs, ijms, ijgi, jcdd, jcm, jdb, jfb, joi, jlpea, jmse, jpcg, jpm, jrfm, jsan, land, laws, life, lubricants, machines, marinedrugs, materials, mathematics, medicalsciences, membranes, metabolites, metals, microarrays, micromachines, microorganisms, minerals, molbank, molecules, nanomaterials, nutrients, optics, pathogens, pharmaceuticals, pharmaceutics, pharmacy, plants, polymers, processes, proteomes, publications, religions, remotesensing, resources, risks, robotics, sensors, socialsciences, societies, sports, sustainability, symmetry, systems, technologies, toxics, toxins, vaccines, veterinarysciences, viruses, water}} 

%% To choose the type of manuscript
\DeclareOption{article}{\gdef\@arttype{Article}}
\DeclareOption{review}{\gdef\@arttype{Review}}
\DeclareOption{communication}{\gdef\@arttype{Communication}}
\DeclareOption{commentary}{\gdef\@arttype{Commentary}}
\DeclareOption{bookreview}{\gdef\@arttype{Book Review}}
\DeclareOption{correction}{\gdef\@arttype{Correction}}
\DeclareOption{addendum}{\gdef\@arttype{Addendum}}
\DeclareOption{editorial}{\gdef\@arttype{Editorial}}
\DeclareOption{changes}{\gdef\@arttype{Changes}}
\DeclareOption{supfile}{\gdef\@arttype{Supfile}}

%% To choose the status of the manuscript
\DeclareOption{submit}{\gdef\@status{submit}}
\DeclareOption{accept}{\gdef\@status{accept}}

%% To choose the whether there is one or more authors
\DeclareOption{oneauthor}{\gdef\@authornum{author}}
\DeclareOption{moreauthors}{\gdef\@authornum{authors}}
\DeclareOption{10pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ExecuteOptions{entropy,12pt,a4paper,article,submit,oneauthor}
\ProcessOptions\relax

\LoadClass[12pt]{article}

\RequirePackage{calc}
\RequirePackage{indentfirst}
\RequirePackage{times,fancyhdr}
\RequirePackage{graphicx}
\RequirePackage{lastpage}
\RequirePackage{ifthen}
\RequirePackage{lineno}
\RequirePackage{float}
\RequirePackage{amsmath}

%% Definition of mathematics environments like theorems, propositions, and lemmas
\RequirePackage{amsthm}
\newtheoremstyle{mdpi}% name
{12pt}% space above
{12pt}% space below
{\itshape}% body font
{}% hndent amount 1
{\bfseries}% theorem head font
{.}% punctuation after theorem head
{.5em}% space after theorem head
{}% theorem head spec (can be left empty, meaning `normal')

%% Adjustments in the proof environment (corresponding to the MDPI Word template)
\renewcommand{\qed}{\unskip\nobreak\quad\qedsymbol} %% This places the symbol right after the text instead of placing it at the end on the line. What will prevent a line break before the symbol?


\renewenvironment{proof}[1][\proofname]{\par %% \proofname allows to have "Proof of my theorem"
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \bfseries %% "Proof" is bold
    #1\@addpunct{.}]\ignorespaces %% Period instead of colon
}{%
  \popQED\endtrivlist\@endpefalse
}

%\RequirePackage{amssymb}
%    \renewenvironment{proof}[1][\proofname]{\par %% \proofname allows to have "Proof of my theorem"
%   %
%      \normalfont \topsep6\p@\@plus6\p@\relax
%      \trivlist
%      \item[\hskip\labelsep
%            \bfseries %% "Proof" is bold
%        #1\@addpunct{.}]\ignorespaces %% Period instead of colon
%    }{%
%     \unskip\nobreak\quad\qedsymbol\endtrivlist\@endpefalse %% I use \unskip\nobreak\quad\qedsymbol instead of $\square$ (puts the symbol right after the text) or \qed (puts the symbol at the end on the line): This will prevent a line break before the symbol.
%    }
%    %% I still need to implement a way to get the qed symbol on the right side if the proof ends with a numbered equation.

\floatstyle{plaintop}
\restylefloat{figure}
\restylefloat{table}
\usepackage{caption}
\captionsetup{position=top, margin=1cm, labelfont=bf, labelsep=period, skip=12pt, justification=justified}
\RequirePackage{color}
\ifthenelse{\equal{\@journal}{Energies}}{\definecolor{logocolor}{rgb}{0.6,0.2,0}}{}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[sort&compress]{natbib}
\bibpunct{[}{]}{,}{n}{}{}
\RequirePackage{hyphenat}
\hyphenpenalty=2000\exhyphenpenalty=2000\sloppy

\renewcommand\NAT@set@cites{%
  \ifNAT@numbers
    \ifNAT@super \let\@cite\NAT@citesuper
       \def\NAT@mbox##1{\unskip\nobreak\textsuperscript{##1}}%
       \let\citeyearpar=\citeyear
       \let\NAT@space\relax
       \def\NAT@super@kern{\kern\p@}%
    \else
       \let\NAT@mbox=\mbox
       \let\@cite\NAT@citenum
       \let\NAT@space\relax
       \let\NAT@super@kern\relax
    \fi
    \let\@citex\NAT@citexnum
    \let\@biblabel\NAT@biblabelnum
    \let\@bibsetup\NAT@bibsetnum
    \renewcommand\NAT@idxtxt{\NAT@name\NAT@spacechar\NAT@open\NAT@num\NAT@close}%
    \def\natexlab##1{}%
    \def\NAT@penalty{\penalty\@m}%
  \else
    \let\@cite\NAT@cite
    \let\@citex\NAT@citex
    \let\@biblabel\NAT@biblabel
    \let\@bibsetup\NAT@bibsetup
    \let\NAT@space\NAT@spacechar
    \let\NAT@penalty\@empty
    \renewcommand\NAT@idxtxt{\NAT@name\NAT@spacechar\NAT@open\NAT@date\NAT@close}%
    \def\natexlab##1{##1}%
  \fi}

\renewcommand{\baselinestretch}{1.19}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[unicode=false, pdftoolbar=true, pdfmenubar=true, bookmarksopen={true},
pdffitwindow=true, pdfnewwindow=true, colorlinks=true,
linkcolor=blue, citecolor=blue, urlcolor=blue, hyperfootnotes=false]{hyperref}
\newcommand{\org@maketitle}{}% LATEX-Check
\let\org@maketitle\maketitle
\def\maketitle{%
\hypersetup{
pdftitle={\@Title},
pdfsubject={\@abstract},
pdfkeywords={\@keyword}
}%
\org@maketitle
}
\renewcommand{\@pdfauthor}{\@Author}

%% Footnotes (corresponding to the MDPI Word template)
\RequirePackage[hang]{footmisc}
\setlength{\skip\footins}{1.2cm}
\setlength{\footnotemargin}{5mm}
\def\footnoterule{\kern-14\p@
\hrule \@width 2in \kern 11.6\p@}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{url}
\urlstyle{same}
\clubpenalty=10000
\widowpenalty=10000
\displaywidowpenalty=10000

%%%%For tracking changes
%\ifthenelse{\equal{\@status}{accept}}{\newcommand{\cor}[2]{{#2}}}{
%\newcommand{\cor}[2]{{\textcolor{red}{\st{#1 }}}\textcolor[rgb]{0.25,0,0.5}{#2}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\firstargument}{}
\newcommand{\Title}[1]{\gdef\@Title{#1}}%
\newcommand{\Author}[1]{\gdef\@Author{#1}}%
\newcommand{\lastpage}[1]{\gdef\@lastpage{#1}}
\newcommand{\doinum}[1]{\gdef\@doinum{#1}}
\newcommand{\pubvolume}[1]{\gdef\@pubvolume{#1}}
\newcommand{\pubyear}[1]{\gdef\@pubyear{#1}}
\newcommand{\address}[2][]{\renewcommand{\firstargument}{#1}\gdef\@address{#2}}
\newcommand{\corresfirstargument}{}
\newcommand{\corres}[2][]{\renewcommand{\corresfirstargument}{#1}\gdef\@corres{#2}}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}
\newcommand{\history}[1]{\gdef\@history{#1}} \def\@pacs{}
\newcommand{\PACS}[1]{\gdef\@pacs{#1}} \def\@msc{}
\newcommand{\MSC}[1]{\gdef\@msc{#1}} \def\@jel{}
\newcommand{\JEL}[1]{\gdef\@jel{#1}}
\newcommand{\keyword}[1]{\gdef\@keyword{#1}}

%% Define the journal name for the header using the ifthen package
\newcommand{\journalname}{%
  \ifthenelse{\equal{\@journal}{Energies}}{Energies}{}%
  }
  
%% Define the logo size of the journal using the ifthen package
\newcommand{\logosize}{%
  \ifthenelse{\equal{\@journal}{Energies}}{\fontsize{32}{32}}{}%
  }
  
%% Creates the command that makes the logo of the journal.
\newcommand{\logo}{%
    \ifthenelse{\equal{\@journal}{Energies}}{\includegraphics[width=7cm]{logo}}{}%
}

%% Creates the ISSN for the journal using the ifthen package
\newcommand{\issn}{%
  \ifthenelse{\equal{\@journal}{Energies}}{Energies}{}%
  }
  
%% www.mdpi.com/journal/\logo
\newcommand{\web}{%
  \ifthenelse{\equal{\@journal}{Energies}}{http://sciforum.net/conference/ece-1}{}%
}

%% Define the length of the header on the front page
\newcommand{\logolength}{%
  \ifthenelse{\equal{\@journal}{Energies}}{\begin{minipage}[t][17mm][t]{0.97\textwidth}}{}%
 }

%% Definde the header for the front page
\ifthenelse{\equal{\@arttype}{Supfile}}
{%
  \newcommand{\header}{%
    \thispagestyle{empty}%
  \begin{flushleft}%
    \vspace*{-50pt}%
  	\textbf{Supplementary file}%
  \end{flushleft}%
  }%
}%
{%
  \newcommand{\header}{%
\thispagestyle{empty}
\logolength
\begin{flushleft}
  \vspace{-36pt}
  \hspace{-5mm}%{\ifthenelse{\equal{\@status}{submit}}{\normalfont Submitted to {\em \journalname}. Pages \thepage \ - \color{black}{\pageref{LastPage}}.
%}{\normalfont {\em \journalname}\ {\bfseries {\@pubyear}}, {\em \@pubvolume},
%\thepage -\@lastpage; doi:\@doinum}}
  \end{flushleft}

%% Creates command that produces the logo on the first page of an accepted paper. For drafts the logo is made in white so that it cannot be seen, but leave the formatting unchanged
\vspace{-28pt}
\begin{flushright}
      {\fontsize{9}{9}\selectfont\bfseries{\colorbox{cyan}{\textcolor{white}{OPEN ACCESS}}}}\\[3pt]
% {\fontsize{10}{10}\selectfont\bfseries{\colorbox{cyan}{\textcolor{white}{~OPEN ACCESS~}}}}\\[8pt]
% This is the solution to be really comparable to the Word template
\ifthenelse{\equal{\@status}{submit}}{
        {{\logosize}{\logosize}\selectfont\bfseries\itshape \textcolor{white}{\logo}}\\
%        \normalfont\bfseries \textcolor{white}{ISSN \issn }\\[-2pt]
        \normalfont \textcolor{white}{www.mdpi.com/}
        }
        {{\logosize\selectfont\bfseries\itshape \textcolor{logocolor}{\logo}}\\
 
%       \normalfont\bfseries ISSN \issn\\[-2pt]
        \normalfont \web
        }
\end{flushright}
 \end{minipage}}
}

%% Maketitle
\renewcommand{\@maketitle}{%
\header

%%Title,author, address, abstract, keywords
\ifthenelse{\equal{\@arttype}{Supfile}}{}{
\begin{flushleft}%
 {%
 \fontsize{12}{12}\selectfont
  \vspace{0pt}
 \textit{Conference Proceedings Paper - Energies ``Whither Energy Conversion? Present Trends, Current Problems and Realistic Future Solutions''\\}
 \vspace{6pt}
 }%
  {%3
   \fontsize{18}{18}\selectfont
   \bfseries{\@Title}
   \par
  }%3
  \vspace{12pt}%
  {%4
   \bfseries{\@Author}
   \par
  }%4
  \vspace{12pt}%
{%6
\ifthenelse{\equal{\firstargument}{1}}{}{\hangafter=1\hangindent=0.7em\noindent}%
\@address
\par
}%6
\vspace{12pt}%
{%8
\ifthenelse{\equal{\@authornum}{authors}}{\hangafter=1\hangindent=0.7em\noindent
{\textbf{*}} \ifthenelse{\equal{\corresfirstargument}{2}}{Authors}{Author} to whom correspondence should be addressed; \@corres
\par
\vspace{12pt}}{}
}%8
\em
{%9
\ifthenelse{\equal{\@status}{submit}}{Version {\@ \today} submitted to {\em
\@journal}. Typeset by \LaTeX{} using class file mdpi.cls}{\@history}\par
}%9
\end{flushleft}}
}%End of maketitle

%% Command for typsetting abstract, kewyords, PACS, MSC, and JEL
\newcommand{\abstractkeywords}{%
\vspace{12pt}%
\hrule

%% Specifies how the abstract should be typeset
{%10
\begingroup
 \vspace{6mm}
\leftskip1cm
\rightskip\leftskip
\parindent0em
  \noindent\textbf{Abstract:\space}\@abstract
  \vspace{3mm}
  \par
  \endgroup
}%10

%% Specifies how the keywords should be typeset and inserts a horizontal line afterwards if PACS and/or MSC and/or JEL are specified they are inserted after keywords, but before the line
{%11
\begingroup
 \vspace{3pt}
\leftskip1cm
\rightskip\leftskip
\parindent0em
     \textbf{Keywords:\space}\@keyword
 \vspace{12pt}
 \par
 \endgroup
}%11

%% Specifies how PACS should be typeset
{%12
\ifthenelse{\equal{\@pacs}{\@empty}}{}{%
\begingroup
\leftskip1cm
\rightskip\leftskip
\parindent0em
  \noindent\textbf{Classification: PACS\space} \@pacs
  \vspace{12pt}
  \par
  \endgroup}%
}%12

%% Specifies how MSC should be typeset
{%13
\ifthenelse{\equal{\@msc}{\@empty}}{}{%
\begingroup
\leftskip1cm
\rightskip\leftskip
\parindent0em
\noindent\textbf{Classification: MSC\space} \@msc
	\vspace{12pt}
   \par
  \endgroup}%%
}%13

%% Specifies how JEL should be typeset
{%13
\ifthenelse{\equal{\@jel}{\@empty}}{}{%
\begingroup
\leftskip1cm
\rightskip\leftskip
\parindent0em
\noindent\textbf{Classification: JEL\space} \@jel
	\vspace{12pt}
   \par
  \endgroup}%%
}%13
\vspace{6pt}
\hrule
\vspace{27pt}
}%End of Abstract and Keywords
%
%
\ifthenelse{\equal{\@arttype}{Supfile}}%
{%
  \AtBeginDocument{%
    \maketitle%
    \thispagestyle{empty}%
    \let\maketitle\relax%
    \ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}%
  }%
}%
{%
  \AtBeginDocument{%
    \maketitle
    \thispagestyle{empty}
    \let\maketitle\relax
    \ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
    \abstractkeywords
  }%
}%

%% Specifies how section headings should be typeset
\renewcommand{\thesection}{\arabic{section}}
\renewcommand{\section}{ %
  \@startsection{section}{1}{0pt}{12pt}{12pt}{\normalsize\bfseries}}

\renewcommand{\thesubsection}{\arabic{section}.\arabic{subsection}}
\renewcommand{\subsection}{ %
  \@startsection{subsection}{2}{0pt}{12pt}{12pt}{\normalsize\itshape}}

\renewcommand{\thesubsubsection}{\arabic{section}.\arabic{subsection}.\arabic{subsubsection}}
\renewcommand{\subsubsection}{ %
  \@startsection{subsubsection}{3}{0pt}{12pt}{12pt}{\normalsize}}

%% Dot after number of section, but not in ref
\let\@@seccntformat\@seccntformat
\renewcommand*{\@seccntformat}[1]{%
  \expandafter\ifx\csname @seccntformat@#1\endcsname\relax
    \expandafter\@@seccntformat
  \else
    \expandafter
      \csname @seccntformat@#1\expandafter\endcsname
  \fi
    {#1}%
}

%\newcommand*{\@seccntformat@subsubsection}[1]{%
%  \csname the#1\endcsname
%}

\renewcommand*{\@@seccntformat}[1]{%
  \csname the#1\endcsname.
}

%% Special section title style
\newcommand{\acknowledgements}[1]{%
    \par\vspace{12pt}\noindent\textbf{#1}%
    \par\vspace{12pt}}

%% Special section title style
\newcommand{\conflictofinterests}[1]{%
    \par\vspace{12pt}\noindent\textbf{#1}%
    \par\vspace{12pt}}    

%% Fix for two line titles in section
\def\section{\@ifstar\unnumberedsection\numberedsection}
\def\numberedsection{\@ifnextchar[%]
  \numberedsectionwithtwoarguments\numberedsectionwithoneargument}
\def\unnumberedsection{\@ifnextchar[%]
  \unnumberedsectionwithtwoarguments\unnumberedsectionwithoneargument}
\def\numberedsectionwithoneargument#1{\numberedsectionwithtwoarguments[#1]{#1}}
\def\unnumberedsectionwithoneargument#1{\unnumberedsectionwithtwoarguments[#1]{#1}}
\def\numberedsectionwithtwoarguments[#1]#2{%
  \ifhmode\par\fi
  \removelastskip
  \vskip 3ex\goodbreak
  \refstepcounter{section}%
  \noindent
  \leavevmode
  \begingroup
  \normalsize\bfseries
  \thesection.\
  #2 \vspace{12pt}
  \endgroup
  \addcontentsline{toc}{section}{%
    \protect\numberline{\thesection}%
    #1}%
  }
\def\unnumberedsectionwithtwoarguments[#1]#2{%
  \ifhmode\par\fi
  \removelastskip
  \vskip 3ex\goodbreak
%  \refstepcounter{section}%
  \noindent
  \leavevmode
  \begingroup
  \bfseries

%  \thesection\
  #2\quad
  \endgroup
  \addcontentsline{toc}{section}{%
%    \protect\numberline{\thesection}%
    #1}%
  }
  
%% Subsection fix for line indent
\def\subsection{\@ifstar\unnumberedsubsection\numberedsubsection}
\def\numberedsubsection{\@ifnextchar[%]
  \numberedsubsectionwithtwoarguments\numberedsubsectionwithoneargument}
\def\unnumberedsubsection{\@ifnextchar[%]
  \unnumberedsubsectionwithtwoarguments\unnumberedsubsectionwithoneargument}
\def\numberedsubsectionwithoneargument#1{\numberedsubsectionwithtwoarguments[#1]{#1}}
\def\unnumberedsubsectionwithoneargument#1{\unnumberedsubsectionwithtwoarguments[#1]{#1}}
\def\numberedsubsectionwithtwoarguments[#1]#2{%
  \ifhmode\par\fi
  \removelastskip
  \vskip 3ex\goodbreak
  \refstepcounter{subsection}%
  \noindent
  \leavevmode
  \begingroup
  \normalsize\itshape
  \thesubsection.\
  #2 \vspace{12pt}
  \endgroup
  \addcontentsline{toc}{subsection}{%
    \protect\numberline{\thesubsection}%
    #1}%
  }
\def\unnumberedsubsectionwithtwoarguments[#1]#2{%
  \ifhmode\par\fi
  \removelastskip
  \vskip 3ex\goodbreak
%  \refstepcounter{subsection}%
  \noindent
  \leavevmode
  \begingroup
  \bfseries
%  \thesubsection\
  #2\quad
  \endgroup
  \addcontentsline{toc}{subsection}{%
%    \protect\numberline{\the}%
    #1}%
  }

%\renewcommand*{\p@section}{\arabic{section}.}
%\renewcommand*{\p@subsection}{\p@section\thesection~}
%\renewcommand*{\p@subsubsection}{\p@subsection\thesubsection~}

%% Defines the appendix
\renewcommand{\appendix}{\par
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \setcounter{subsubsection}{0}%
  \gdef\thesection{\@Alph\c@section}%
  \gdef\thesubsection{\@Alph\c@section.\@arabic\c@subsection}%
  \gdef\theHsection{\@Alph\c@section.}%
  \gdef\theHsubsection{\@Alph\c@section.\@arabic\c@subsection}%
  \csname appendixmore\endcsname
}

%% Specifies how captions should be typeset
\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize{\bfseries #1}. #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize{\bfseries #1}. #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}


\setlength{\oddsidemargin}{17.5mm}
\setlength{\voffset}{-1in}
\setlength{\hoffset}{-1in}
\setlength{\topmargin}{17.5mm}
\setlength{\headsep}{0mm}
\setlength{\textheight}{250mm}
\setlength{\textwidth}{175mm}
\setlength{\textfloatsep}{12pt}
\setlength{\abovedisplayskip}{0pt}
\setlength{\belowdisplayskip}{0pt}
\setlength{\parindent}{5mm}
\setlength{\abovecaptionskip}{12pt}
\setlength{\belowcaptionskip}{12pt}
\setlength{\itemsep}{0pt}
\setlength{\partopsep}{0pt}
\setlength{\parsep}{0pt}
\ifthenelse{\equal{\@arttype}{Supfile}}
{%
  \renewcommand{\thefigure}{S\arabic{figure}}%
  \renewcommand{\thetable}{S\arabic{table}}%
}{}%

%% Create headings for pages except the first
\newcommand{\heading}[1]{\gdef\@heading{#1}}
\setlength{\headheight}{8.5pt}
\setlength{\headsep}{25.5pt}

\def\ps@myheadings{%
    \def\@oddfoot{}
    \let\@evenfoot\@oddfoot
    \def\@evenhead{%
     
     {\ifthenelse{\equal{\@status}{submit}}{ \ifthenelse{\equal{\@arttype}{Supfile}}{}{Version {\@ \today} submitted to {\em \journalname}}%
        \hfil {\bfseries \thepage \ of \pageref{LastPage}}%
}{\ifthenelse{\equal{\@arttype}{Supfile}}{}{{\em \journalname} {\bfseries \@pubyear}, {\em \@pubvolume}}%
        \hfill {\bfseries \thepage}}%
        \vspace{50pt}}%
       }
    \let\@oddhead\@evenhead
    \let\@mkboth\@gobbletwo
    \let\sectionmark\@gobble
    \let\subsectionmark\@gobble
}

\pagestyle{myheadings}

%% Bibliography
\renewcommand\@biblabel[1]{#1. }

\def\thebibliography#1{\vspace{12pt}
\noindent{{\bfseries References}}\vspace{12pt}%
\list{{\arabic{enumi}}}{\def\makelabel##1{\hss{##1}}\topsep=0\p@\parsep=0\p@
\partopsep=0\p@\itemsep=0\p@
\labelsep=1ex
\itemindent=0\p@
\settowidth\labelwidth{\footnotesize[#1]}%
\leftmargin\labelwidth
\advance\leftmargin\labelsep
%\advance\leftmargin -\itemindent
\usecounter{enumi}}
%\def\newblock{\ }
%\sloppy\clubpenalty4000\widowpenalty4000
%\sfcode`\.=1000\relax
}
\let\endthebibliography=\endlist

%% Creates command that produces the copyright information
\newcommand{\cright}{%
\ifthenelse{\equal{\@arttype}{Supfile}}{}{%
\vspace{12pt}\noindent \copyright
\ifthenelse{\equal{\@status}{submit}}{\ {\@ \today} by the
\@authornum; submitted to {\em \journalname} for possible open
access publication under the terms and conditions of the
Creative Commons Attribution license
http://creativecommons.org/licenses/by/3.0/. }{\ {\@pubyear} by
the \@authornum; licensee MDPI, Basel, Switzerland. This article is an
open access article \linebreak distributed under the terms and conditions
of the Creative Commons Attribution license \linebreak
(http://creativecommons.org/licenses/by/3.0/).}}}

\endinput
